Header menu logo FSharp.Control.AsyncSeq

AsyncSeq.AsyncSeqBuilder Type

Computation builder that allows creating of asynchronous sequences using the 'asyncSeq { ... }' syntax

Constructors

Constructor Description

AsyncSeqBuilder()

Full Usage: AsyncSeqBuilder()

Returns: AsyncSeqBuilder

Internal use only

Returns: AsyncSeqBuilder

Instance members

Instance member Description

this.Bind

Full Usage: this.Bind

Parameters:
Returns: AsyncSeq<'U>

Implements binding for the asyncSeq computation builder.

source : Async<'T>
body : 'T -> AsyncSeq<'U>
Returns: AsyncSeq<'U>

this.Combine

Full Usage: this.Combine

Parameters:
Returns: AsyncSeq<'T>

Implements sequential composition for the asyncSeq computation builder.

seq1 : AsyncSeq<'T>
seq2 : AsyncSeq<'T>
Returns: AsyncSeq<'T>

this.Delay

Full Usage: this.Delay

Parameters:
Returns: AsyncSeq<'T>

Implements delay for the asyncSeq computation builder.

f : unit -> AsyncSeq<'T>
Returns: AsyncSeq<'T>

this.For

Full Usage: this.For

Parameters:
Returns: AsyncSeq<'TResult>

Implements "for" loops for the asyncSeq computation builder. Asynchronous for loop - for all elements from the input sequence, generate all elements produced by the body (asynchronously). See also the AsyncSeq.collect function.

source : AsyncSeq<'T>
action : 'T -> AsyncSeq<'TResult>
Returns: AsyncSeq<'TResult>

this.For

Full Usage: this.For

Parameters:
    source : 'T seq
    action : 'T -> AsyncSeq<'TResult>

Returns: AsyncSeq<'TResult>

For loop that iterates over a synchronous sequence (and generates all elements generated by the asynchronous body)

source : 'T seq
action : 'T -> AsyncSeq<'TResult>
Returns: AsyncSeq<'TResult>

this.TryFinally

Full Usage: this.TryFinally

Parameters:
    body : AsyncSeq<'T>
    compensation : unit -> unit

Returns: AsyncSeq<'T>

Implements "try-finally" for the asyncSeq computation builder.

body : AsyncSeq<'T>
compensation : unit -> unit
Returns: AsyncSeq<'T>

this.TryWith

Full Usage: this.TryWith

Parameters:
Returns: AsyncSeq<'T>

Implements "try-with" for the asyncSeq computation builder.

body : AsyncSeq<'T>
handler : exn -> AsyncSeq<'T>
Returns: AsyncSeq<'T>

this.Using

Full Usage: this.Using

Parameters:
    resource : 'T
    binder : 'T -> AsyncSeq<'U>

Returns: AsyncSeq<'U>

Implements "use" for the asyncSeq computation builder.

resource : 'T
binder : 'T -> AsyncSeq<'U>
Returns: AsyncSeq<'U>

this.While

Full Usage: this.While

Parameters:
    guard : unit -> bool
    body : AsyncSeq<'T>

Returns: AsyncSeq<'T>

Implements "while" for the asyncSeq computation builder.

guard : unit -> bool
body : AsyncSeq<'T>
Returns: AsyncSeq<'T>

this.Yield

Full Usage: this.Yield

Parameters:
    value : 'T

Returns: AsyncSeq<'T>

Implements "yield" for the asyncSeq computation builder.

value : 'T
Returns: AsyncSeq<'T>

this.YieldFrom

Full Usage: this.YieldFrom

Parameters:
    source : 'T seq

Returns: AsyncSeq<'T>

Implements "yield!" for a synchronous sequence in the asyncSeq computation builder.

source : 'T seq
Returns: AsyncSeq<'T>

this.YieldFrom

Full Usage: this.YieldFrom

Parameters:
Returns: AsyncSeq<'T>

Implements "yield!" for the asyncSeq computation builder.

source : AsyncSeq<'T>
Returns: AsyncSeq<'T>

this.Zero

Full Usage: this.Zero

Returns: AsyncSeq<'T>

Implements empty for the asyncSeq computation builder.

Returns: AsyncSeq<'T>

Type something to start searching.