AsyncSeqSrc Module
Operations on async sequence sources.
Functions and values
| Function or value |
Description
|
|
Closes the async sequence source casuing any created async sequences to complete.
|
|
|
|
Causes async sequence created before the call to raise an exception.
|
|
Causes any async sequences created before the call to yield the item.
|
|
Creates an async sequence which yields values as they are put into the source and terminates when the source is closed. This sequence will yield items starting with the next put. Many async sequences can be created from once source.
|
FSharp.Control.AsyncSeq