AsyncSeq.AsyncSeqBuilder Type
Computation builder that allows creating of asynchronous sequences using the 'asyncSeq { ... }' syntax
Constructors
| Constructor |
Description
|
|
Internal use only
|
Instance members
| Instance member |
Description
|
|
|
|
|
Implements "for" loops for the asyncSeq computation builder. Asynchronous for loop - for all elements from the input sequence, generate all elements produced by the body (asynchronously). See also the AsyncSeq.collect function.
|
|
|
|
|
|
|
|
|
|
|
|
|
Implements "yield!" for a synchronous sequence in the asyncSeq computation builder.
|
|
|
Implements empty for the asyncSeq computation builder.
|
FSharp.Control.AsyncSeq